@@ -7,6 +7,7 @@ import MediaWikiParser
 import LatexRenderer
 import HtmlRenderer
 import Tools
+import System.FilePath.Posix
 import qualified Data.Map as Map
 import Data.Set ()
 import Control.Monad.State
@@ -18,7 +19,13 @@ import Data.ByteString
  
 
 
-  
+runCompile ::String ->  ImperativeMonad ()
+runCompile dir = do t<-liftIO $ Tools.readFile (dir </> "input")
+                    cr<-return (printPrepareTree (parseit minparsers t)) 
+                    liftIO $ Tools.writeFile (dir </> "output") (show cr)
+
+
+
 {-DHUN| main function to compile mediawiki pages   |DHUN-}
  
 compile ::
@@ -39,9 +46,15 @@ compile theRunMode text templates tabs mytitle mylanguage formulas b
                         (hostname . fullUrl $ st)
                         templates
                         tabs formulas)
+           Book -> do
+                    return
+                     (run b mylanguage mytitle (loadacu st) (loadacu st)
+                        (hostname . fullUrl $ st)
+                        templates
+                        tabs formulas)
            ExpandedTemplates -> return
-                                  (run b mylanguage mytitle (parseit parsers text) (parseit parsers text) (hostname . fullUrl $ st) templates
-                                     tabs formulas)
+                                    (run b mylanguage mytitle (parseit parsers text) (parseit parsers text) (hostname . fullUrl $ st) templates
+                                      tabs formulas)
  
 {-DHUN| pathname of the temporary directory of the compiler |DHUN-}
  
@@ -110,9 +123,9 @@ postproctabmap m = Map.map f m
 data CompileResult = CompileResult{images :: [String],
                                    body :: String, tablelist :: [[String]],
                                    galleryNumbers :: [Integer], title :: String, html::String}
- 
+ deriving Show
 {-DHUN| the first parameter is the parse tree created by get parse of the document currently being processed. the second parameter is the URL under which the document was downloaded. the third parameter is the netloc describing the wiki this page belongs to. The fourth parameter is a mapping file defined by the user for the mapping of mediawiki templates to latex commands. the fifth parameter is a possible parse tree created by precious run the the should be added before the begging of the newly created parse tree. This function writes out all results to temporary files that will be further processed by compiler.py DHUN-}
- 
+
 run ::
     Bool -> Maybe String -> String -> [Anything Char] -> [Anything Char] ->
       String -> String -> [[ByteString]] -> Map.Map String Int-> CompileResult
