@@ -4,7 +4,7 @@ import MegaFont
 import BaseFont
 import Data.Char
 import Data.Array
-import Data.Map hiding ((!))
+import Data.Map.Strict hiding ((!))
 import Data.Maybe
 import System.Info
  
@@ -12,7 +12,7 @@ import System.Info
  
 megafont2 :: Map FontStyle (Array Int Char)
 megafont2
-  = Data.Map.fromList
+  = Data.Map.Strict.fromList
       [(s,
         array ((0, (2 :: Int) ^ (16 :: Int) - 1) :: (Int, Int))
           (zip ([0 .. (2 :: Int) ^ (16 :: Int) - 1] :: [Int]) f))
@@ -23,7 +23,7 @@ megafont2
 getFont :: FontStyle -> Char -> Font
 getFont fontStyle c
   = fromMaybe GnuUnifont
-      ((Data.Map.lookup fontStyle megafont2) >>=
+      ((Data.Map.Strict.lookup fontStyle megafont2) >>=
          return . fromCharToFont . (! (if (ord c) >65535 then ord (' ') else (ord c))))
  
 {-DHUN| Takes a font and returns the LaTeX Command to switch to this particular font in xelatex DHUN-}
