@@ -12,8 +12,6 @@ import Control.Monad.State
 import Data.List
 import Tools
 import System.FilePath
-import Control.Concurrent.MVar
-import Parallel
  
 modpath2 :: String -> URL -> URL
 modpath2 s u
@@ -97,13 +95,14 @@ doImage ::
           WikiUrl ->
             (Integer, String) -> IO (Maybe ImageInfo)
 doImage dir theWikiUrl img
-  = do p <- getImagePage dir theWikiUrl (fst img, theName)
+  = do myprint (show img)
+       p <- getImagePage dir theWikiUrl (fst img, theName)
        case p of
            Just (u, pp, du) -> return (Just ImageInfo{wikiFilename=theName,imageNumber=pp,contributorUrls=u,descriptionUrl=du})
            _ -> return Nothing
   where theName
           = case dropWhile (/= ':') (takeWhile (/= '|') (snd img)) of
-                (_ : xs) -> xs
+                (_ : xs) -> replace2 xs "%" "%25"
                 _ -> []
  
 {-DHUN| main function to download images. It takes the temporary image download directory as first parameter. It takes image include strings of the images from the wiki source, that is the text in between the square brackets as second input parameter. It takes the WikiUrl of the wiki websitze currently being processed as thrird parameter. This function runs as a background process. So it returns a list of empty MVars immediately when being called. They are later on filled with information on the downloaded images including their location in the temporary image download directory. The returend MVars contain ImageInfo values. See description in the module ImperativeState for a detailed description. DHUN-}
@@ -112,11 +111,10 @@ getImages ::
           String ->
             [String] ->
               WikiUrl ->
-                ImperativeMonad [MVar (Maybe ImageInfo)]
+                ImperativeMonad [Maybe ImageInfo]
 getImages dir images theWikiUrl
-  = do st<-get
-       liftIO $
-         do ddir <- base (counter st) dir
-            thetheWikiUrl <- base (counter st) theWikiUrl
-            iimages <- mapM (base (counter st)) ((zip [1 ..] images))
-            (mapM (liftA3 (counter st) doImage ddir thetheWikiUrl) iimages)
+  = do liftIO $
+         do let ddir = dir
+            let thetheWikiUrl = theWikiUrl
+            let iimages = ((zip [1 ..] images))
+            (mapM (doImage ddir thetheWikiUrl) iimages)
