@@ -1,8 +1,9 @@
 {-DHUN| module defining the datatypes needed for the outer imperative flow control of the program. All configurtion information needed for single run of the program is stored here. DHUN-}
 module ImperativeState where
-import Data.Map
+import Data.Map.Strict
 import Control.Monad.State
 import Control.Monad.Except
+import MediaWikiParseTree
 import UrlAnalyse
 import Control.Concurrent.MVar
 import Data.List
@@ -56,26 +57,28 @@ myplus :: Contributor -> Contributor -> Contributor
 myplus x y = x{edits = (edits x) + (edits y)}
  
 contribsum :: [Map String Contributor] -> Map String Contributor
-contribsum x = Data.List.foldl (unionWith myplus) Data.Map.empty x
+contribsum x = Data.List.foldl (unionWith myplus) Data.Map.Strict.empty x
  
 imperativeStateZero :: IO ImperativeState
 imperativeStateZero
   = do v<-newMVar (0::Int)
        return ImperativeState{audict = [], fullUrl = fullWikiUrlZero,
-                    tmpPath = "" ,counter=v}
+                    tmpPath = "" ,counter=v, loadacu=[]}
  
 data ImperativeState = ImperativeState{audict ::
-                                       [MVar (Map String Contributor)],
-                                       fullUrl :: FullWikiUrl, tmpPath :: String, counter::MVar Int}
+                                       [(Map String Contributor)],
+                                       fullUrl :: FullWikiUrl, tmpPath :: String, counter::MVar Int, loadacu::[Anything Char]}
+
 
 data ImageInfo = ImageInfo{wikiFilename :: String,imageNumber::Integer,contributorUrls::[String],descriptionUrl::URL}
-
+  deriving (Show,Read)
  
 type ImperativeMonad = ExceptT MyError (StateT ImperativeState IO)
  
 data RunMode = HTML
              | ExpandedTemplates
              | StandardTemplates
+             | Book
              | UserTemplateFile String
              deriving (Show, Read, Eq)
  
@@ -89,5 +92,12 @@ data FullConfig = FullConfig{headers :: Maybe String,
                              resolution :: Integer, outputFilename :: String,
                              inputUrl :: String, runMode :: RunMode, paper :: String,
                              vector :: Bool, copy :: Maybe String, mainPath :: String,
-                             server :: Maybe Int, outputType::OutputType, selfTest ::Maybe (Integer,Integer)}
+                             server :: Maybe Int, outputType::OutputType, selfTest ::Maybe (Integer,Integer), compile:: Maybe String, imgctrb:: Maybe String}
                 deriving (Show, Read)
+
+fullconfigbase::FullConfig
+fullconfigbase= FullConfig{headers =Nothing,
+                             resolution =0, outputFilename ="",
+                             inputUrl ="", runMode =HTML, paper ="A4",
+                             vector = False, copy = Nothing, mainPath = "",
+                             server = Nothing, outputType=PlainPDF, selfTest =Nothing, compile= Nothing,imgctrb=Nothing}
