@@ -2,8 +2,12 @@
 module Load where
 import ImperativeState
 import Tools
+import Hex
 import UrlAnalyse
 import Control.Monad.State
+import System.IO.Temp
+import System.Directory
+import System.FilePath.Posix
 import Text.ParserCombinators.Parsec hiding (try)
 import Text.Parsec.Prim
 import Codec.Binary.UTF8.String
@@ -20,8 +24,7 @@ import MediaWikiParseTree
 import MediaWikiParser
 import Network.URL
 import Control.Monad.Except
-import Control.Concurrent
-import Parallel
+import System.Process
  
 notendyet ::
           (String -> ImperativeMonad String) ->
@@ -136,6 +139,26 @@ qIncludeAction wurl text
                         noinclude wurl ("\n\ndhunparserurl " ++ d ++ "\n\n" ++ p)
            _ -> return ""
   where d = (trim (takeWhile (/= '|') text))
+
+qBookIncludeAction :: WikiUrl -> String -> ImperativeMonad String
+qBookIncludeAction wurl text
+  = if isInfixOf "Vorlage" text then return ("{{"++text++"}}")
+     else  
+      do pp <- (liftIO (print d)) >>liftIO (getBookpage d (wurl))
+         case pp of
+           Just p -> do _ <- addContributors d Nothing
+                        x <- noinclude wurl ("\n\ndhunparserurl " ++ d ++ "\n\n" ++ p)
+                        st<- get
+                        systempdir <- liftIO getTemporaryDirectory
+                        tempdir <- liftIO $ createTempDirectory systempdir "MediaWiki2LaTeXParser"
+                        liftIO $ Tools.writeFile (tempdir </> "input") x
+                        _ <- liftIO $ system("mediawiki2latex -x "++( Hex.hex (show (fullconfigbase{compile=Just tempdir}))))
+                        t<-liftIO $  Tools.readFile (tempdir </> "output")
+                        put st{loadacu=((read t)++(loadacu st)::[Anything Char])}
+                        return x
+           _ -> return ""
+  where d = (trim (takeWhile (/= '|') text))
+
  
 makeUrl :: String -> String -> String -> [Char]
 makeUrl lang theFam thePage
@@ -244,7 +267,7 @@ makeBodyHTML m u = concat (map go (sort (toList m)))
 makeContributors :: Maybe URL -> ImperativeMonad (String, String)
 makeContributors uu
   = do st <- get
-       li <- liftIO (mapM readMVar (audict st))
+       li <- liftIO (return (audict st))
        let myaudict = contribsum li
        let theUrl
              = case uu of
@@ -270,7 +293,7 @@ parseUrl u
 getContributors ::
                 [String] ->
                   ImperativeMonad
-                    (MVar ([MVar (Map String Contributor)], [MVar (Maybe String)]))
+                    (([(Map String Contributor)], [(Maybe String)]))
 getContributors u
   = do st <- get
        stz<- liftIO imperativeStateZero
@@ -278,7 +301,7 @@ getContributors u
        au <- mapM go u
        newState <- get
        put st
-       rr <- liftIO (newMVar (audict newState, au))
+       rr <- liftIO (return (audict newState, au))
        return rr
   where go uu
           = do purl <- parseUrl uu
@@ -287,17 +310,17 @@ getContributors u
                addContributors (lemma purl) (Just (UrlAnalyse.url purl))
  
 addContributors ::
-                [Char] -> Maybe URL -> ImperativeMonad (MVar (Maybe String))
+                [Char] -> Maybe URL -> ImperativeMonad ((Maybe String))
 addContributors theLemma uu
   = do sst <- get
        let st = fullUrl sst
-       thetheLemma <- liftIO . (base (counter sst)) $ theLemma
-       thetheHostname <- liftIO . (base (counter sst)) . hostname $ st
-       thetheUU <- liftIO . (base (counter sst)) $ uu
-       au <- (liftIO (((liftA3 (counter sst) (fun sst)) thetheLemma thetheHostname thetheUU)))
-               :: ImperativeMonad (MVar (Map String Contributor, Maybe String))
-       auau <- liftIO ((liftA (counter sst) (return . fst)) au)
-       lic <- liftIO ((liftA (counter sst) (return . snd)) au)
+       thetheLemma <- liftIO $ return theLemma
+       thetheHostname <- liftIO $ return (hostname  st)
+       thetheUU <- liftIO $ return uu
+       au <- (liftIO ((((fun sst)) thetheLemma thetheHostname thetheUU)))
+               :: ImperativeMonad ((Map String Contributor, Maybe String))
+       auau <- liftIO (((return . fst)) au)
+       lic <- liftIO (((return . snd)) au)
        put sst{audict = auau : (audict sst)}
        return lic
   where fun ssst lem ho uuu 
@@ -344,6 +367,13 @@ runActions fu text
        runAction "{{:" "}}" (qIncludeAction wurl) j
   where wurl = wikiUrl fu
  
+runBookActions :: FullWikiUrl -> String -> ImperativeMonad String
+runBookActions fu text
+  = do x <- noinclude wurl text
+       runAction "[[" "]]" (qBookIncludeAction wurl) x
+  where wurl = wikiUrl fu
+
+
 replacements :: String -> String
 replacements x
   = replace2
@@ -366,6 +396,16 @@ loadPlain st uu
              Just p -> do _ <- addContributors (lemma fu) uu
                           runActions fu p
              _ -> throwError (DownloadError (lemma fu) (exportURL (url fu)))
+
+loadBook :: ImperativeState -> Maybe URL -> ImperativeMonad [Char]
+loadBook st uu
+  = let fu = fullUrl st in
+      do pp <- liftIO (getpage (lemma fu) (wikiUrl fu))
+         case pp of
+             Just p -> do _ <- addContributors (lemma fu) uu
+                          runBookActions fu p
+             _ -> throwError (DownloadError (lemma fu) (exportURL (url fu)))
+
  
 loadHTML :: ImperativeState -> ImperativeMonad String
 loadHTML st
@@ -378,6 +418,19 @@ loadHTML st
          x <- liftIO (geturl2 (exportURL (url fu)))
          return . decode . unpack $ x
  
+
+loadBookHTML :: ImperativeState -> ImperativeMonad String
+loadBookHTML st
+  = let fu = fullUrl st in
+      do midst<-get
+         (res,newst)<-liftIO (runStateT (runExceptT (loadPlain st (Just (url fu)))) midst)
+         case res of 
+           Right _->put newst
+           _ -> return ()    
+         x <- liftIO (geturl2 (exportURL (url fu)))
+         return . decode . unpack $ x
+
+
 loadMediaWiki :: ImperativeState -> ImperativeMonad [Char]
 loadMediaWiki st
   = let fu = fullUrl st in
@@ -413,6 +466,7 @@ load theRunMode
   = do st <- get
        case theRunMode of
            HTML -> loadHTML st
+           Book -> loadBook st Nothing
            UserTemplateFile _ -> loadPlain st Nothing
            StandardTemplates -> loadPlain st Nothing
            ExpandedTemplates -> loadMediaWiki st
