@@ -539,7 +539,7 @@ goodtags1
      "title", "frame", "param", "base", "area", "font", "code", "span",
      "abbr", "body", "link", "menu", "math", "meta", "samp", "cite", "head",
      "html", "poem", "form", "cite", "ref", "div", "pre", "sub", "sup",
-     "big", "del", "map", "bdo", "var", "dfn", "kbd", "col", "ins",
+     "big", "del", "map", "bdo", "var", "dfn", "kbd", "col", "ins", "bdi",
      "dir", "img", "h1", "h2", "h3", "h4", "h5", "h6", "li", "ul", "ol",
      "tt", "dd", "dl", "dt", "hr", "em", "b", "i", "s", "u", "p", "q",
      "a"]
