@@ -1,7 +1,7 @@
 {-DHUN| A module for mutable states used in the programm DHUN-}
 module MyState where
 import qualified Data.Map as Map
-import Data.Map (Map)
+import Data.Map.Strict (Map)
 import Control.Monad.Trans.State (State)
 import MediaWikiParseTree
 import BaseFont
