@@ -34,9 +34,14 @@ ppure vv x
 
 {-DHUN| alias to switch between forkOS and forkIO for testing DHUN-}
 
-myFork :: MVar Int ->  IO () -> IO ThreadId
-myFork v x = do i<-takeMVar v
-                if i<100
+myFork :: MVar Int ->  IO () -> IO ()
+myFork v x = x
+
+
+
+{-
+  do i<-takeMVar v
+                if i<1
                   then do putMVar v $!! (i+1)
                           forkIO $ do x
                                       ii<-takeMVar v
@@ -44,7 +49,8 @@ myFork v x = do i<-takeMVar v
                   else do putMVar v $!! i
                           threadDelay 1000
                           myFork v x
-                        
+  
+-}                      
 {-DHUN| takes a function which takes a list and return an IO action as first parameter. It takes a list of MVar containing the same type as the type contained in the list as second parameter. It returnes an empty MVar immediately. As soon as all MVar in the list given as second parameter could be read, the function is started in a new thread. As soon as it finishes, the returend MVar is filled with the value returend by the function DHUN-}
  
 liftList :: MVar Int -> ([a] -> IO b) -> [MVar a] -> IO (MVar b)
