@@ -22,6 +22,7 @@ import Text.Blaze.Internal
 import Data.Time.Clock.POSIX
 import Data.Text (pack)
 import Control.DeepSeq
+import System.Exit
 
 mytext ::String-> H.Html
 mytext = text . pack
@@ -143,7 +144,7 @@ progressBar t sub
                   case filename uu of 
                     Nothing -> do method GET 
                                   ok $
-                                    template "Converting" $ pageFrame $ infoBox (if not (member theIndex m) then "Not enough resources availiable to process your request! Your request has been dropped! Please download the full version for free and run it on your own computer!" else (if not (failed uu) then"Conversion Running" else "Conversion Failed due to timeout")) $
+                                    template "Converting" $ pageFrame $ infoBox (if not (member theIndex m) then "Not enough resources availiable to process your request! Your request has been dropped! Please download the full version for free and run it on your own computer!" else (if not (failed uu) then"Conversion Running" else "Conversion Failed due to timeout or non zero exit code")) $
                                         do H.meta H.! A.httpEquiv "refresh" H.! A.content "1" 
                                            H.table $ 
                                              do H.tr $
@@ -214,11 +215,14 @@ formPage m s
                                     H.select H.! A.style wwidth H.! A.name "output" $
                                       do H.option H.! A.value "pdf" $ "Compiled PDF"  
                                          H.option H.! A.value "zip" $ "Source ZIP"  
+                                         H.option H.! A.value "epub" $ "EPUB File"  
+                                         H.option H.! A.value "odt" $ "ODT File (Word Processor)"  
                              H.tr $
                                do H.td "Template expansion"
                                   H.td $ do
                                     H.select H.! A.style wwidth H.! A.name "expansion" $
                                       do H.option H.! A.value "Print" $ "Print"  
+                                         H.option H.! A.value "BookMode" $ "BookMode"  
                                          H.option H.! A.value "MediaWiki" $ "Mediawiki"  
                                          H.option H.! A.value "Normal" $ "Normal"  
                              H.tr $
@@ -250,6 +254,7 @@ formPage m s
         getRunmode "Print" = ImperativeState.HTML
         getRunmode "MediaWiki" = ImperativeState.ExpandedTemplates  
         getRunmode "Normal" = ImperativeState.StandardTemplates
+        getRunmode "BookMode" = ImperativeState.Book
         getRunmode _ = ImperativeState.HTML
 
         processForm :: ServerPart Response
@@ -261,21 +266,22 @@ formPage m s
                output <- lookBS "output"
                zzz <- liftIO $
                                  do tmpDir <- getTemporaryDirectory
-                                    (name, handle) <- openTempFile tmpDir ("MediaWiki2LaTeX"++if (toString (toStrict output))== "zip" then "zip" else "pdf")
+                                    (name, handle) <- openTempFile tmpDir ("MediaWiki2LaTeX"++if (toString (toStrict output))== "zip" then "zip" else if (toString (toStrict output))== "epub" then "epub" else if (toString (toStrict output))== "odt" then "odt" else "pdf")
                                     hClose handle >> removeFile name
                                     act <- mainAction FullConfig{selfTest=Nothing,headers = Nothing, resolution = 300,
                                       outputFilename = name, inputUrl = (toString (toStrict msg)),
-                                      runMode = getRunmode (toString (toStrict expansion)), paper = (toString (toStrict paperOpt)), vector = (toString (toStrict vectorOpt))=="Keep Vector Form",
-                                      ImperativeState.copy = Nothing, mainPath = "", server = Nothing,outputType=if (toString (toStrict output)) == "zip" then ImperativeState.ZipArchive else ImperativeState.PlainPDF}
+                                      runMode = if (isInfixOf ("Book:"::[Char]) (toString (toStrict msg))) then getRunmode ("BookMode"::[Char]) else getRunmode (toString (toStrict expansion)), paper = (toString (toStrict paperOpt)), vector = (toString (toStrict vectorOpt))=="Keep Vector Form",
+                                      ImperativeState.copy = Nothing, mainPath = "", server = Nothing,outputType=if (toString (toStrict output)) == "zip" then ImperativeState.ZipArchive else if (toString (toStrict output)) == "epub" then ImperativeState.EPubFile else if (toString (toStrict output)) == "odt" then ImperativeState.OdtFile else ImperativeState.PlainPDF, compile=Nothing, imgctrb=Nothing}
                                     yy<-newEmptyMVar
                                     mm<-takeMVar m 
                                     _<-if (not (currentlyrunning mm)) 
                                          then 
                                            do _<-forkIO $ do (i,o,e,h) <- runInteractiveCommand ("mediawiki2latex -x "++act) 
                                                              tt<-getPOSIXTime
-                                                             zz<-forkProgressDriver o m name (if (toString (toStrict output) == "zip") then "zip" else "pdf")
+                                                             let ss = (if (toString (toStrict output))== "zip" then "zip" else if (toString (toStrict output))== "epub" then "epub" else if (toString (toStrict output))== "odt" then "odt" else "pdf") 
+                                                             zz<-forkProgressDriver o m name ss
                                                              putMVar yy zz
-                                                             ex h i e ((realToFrac tt)+3600.0) m zz
+                                                             ex h i e ((realToFrac tt)+3600.0) m zz ss
                                               return ()  
                                           else
                                             do putMVar yy (-1)
@@ -288,8 +294,8 @@ formPage m s
                ok $ toResponse $  template "Redirect" $
                       do H.meta H.! A.httpEquiv "refresh" H.! A.content (stringValue ("0;url=/progress/"++(show zzz)++"."++(if (toString (toStrict output))== "zip" then "html" else "html")))
  
-ex :: ProcessHandle -> Handle -> Handle -> Double -> MVar (Map Int ProgressInfo)-> Int -> IO ()
-ex h i e t m n
+ex :: ProcessHandle -> Handle -> Handle -> Double -> MVar (Map Int ProgressInfo)-> Int -> String -> IO ()
+ex h i e t m n s
      = do tt<-getPOSIXTime
           threadDelay 100                  
           if (realToFrac tt) > t 
@@ -304,8 +310,21 @@ ex h i e t m n
           _<- if xo then System.IO.hGetContents e else return "" 
           y<-getProcessExitCode h
           case y of
-            Just _ -> return ()
-            _-> if (realToFrac tt) > t then return () else ex h i e t m n
+            Just ee -> if ExitSuccess == ee 
+                        then do threadDelay 3000000
+                                mm<-takeMVar m 
+                                putMVar m (Data.Map.Strict.insertWith (\new old-> old{progress=progress new,lastStepTime=realToFrac tt}) n progressInfoZero{progress=1.0} mm) 
+                                mmm<-takeMVar m
+                                putMVar m mmm
+                                case Data.Map.Strict.lookup n mmm of 
+                                  Just yy -> do _ <- takeMVar m 
+                                                putMVar m (Data.Map.Strict.insert n yy{filename=Just s} mmm)
+                                  _ -> return () 
+                        else 
+                         do mm<-takeMVar m
+                            putMVar m (Data.Map.Strict.update (\x->Just x{failed=True}) n mm)
+
+            _-> if (realToFrac tt) > t then return () else ex h i e t m n s
 mylist :: [([Char], Double)]
 mylist=[("downloading article and contributor information", 0.02540431143798292),("parsing article text", 0.057625916241286344),("forking threads to download of images and contributor information on them", 0.058045207449988465),("precompiling table columns", 0.08075814224942594),("joining threads to download the images and contributor information on them", 0.37003149457779727),("preparing for PDF generation", 0.5479855803098518),("preparing images for LaTeX document", 0.637605216120732),("generating PDF file. LaTeX run 1 of 4", 0.6911489294291799),("generating PDF file. LaTeX run 2 of 4", 0.7673758195622185),("generating PDF file. LaTeX run 3 of 4", 0.8463397892914045),("generating PDF file. LaTeX run 4 of 4", 0.9231746180088297),("finished", 1.0)]
 
