@@ -3,8 +3,9 @@
 module Static where
 import Data.FileEmbed
 import Data.ByteString
-import System.Directory
 import Data.ByteString.UTF8
+import System.Directory
+import System.FilePath
 
 --{-DHUN| webImage DHUN-}
  
@@ -29,7 +30,7 @@ createDirectories pathname
   = mapM
       (\ s ->
          (createDirectoryIfMissing True (pathname ++ "/document/" ++ s)))
-      ["images", "headers", "main"]
+      ["images", "headers", "main", "formulas"]
  
 {-DHUN| function to write files to an already created directory in the temporary directory. The first parameter is the pathname of the temporary directory. The second parameter is a list tuples. The first element of each tuple is the relative pathname of the file to be created. The second element of each tuple is the binary data to be written into the file DHUN-}
  
@@ -38,7 +39,7 @@ writeFiles ::
 writeFiles pathname filelist
   = do _ <- (mapM
                (\ (name, content) ->
-                  Data.ByteString.writeFile (pathname ++ name) content)
+                  Data.ByteString.writeFile (pathname </> name) content)
                filelist)
        return ()
  
