@@ -5,11 +5,15 @@ import Data.Char
 import Data.List.Split (splitOn)
 import Control.Monad
 import System.IO
-import Data.List.HT (dropWhileRev)
 import System.IO.Strict
+import Data.Time.Clock.POSIX
 
 
-
+myprint :: String -> IO ()
+myprint s
+  = do t <- getPOSIXTime
+       Prelude.putStrLn ("mediawiki2latex (" ++ (show t) ++ "):" ++ s)
+       hFlush stdout
 
 {-DHUN| Write a unicode string to a utf8 encoded file. The first parameter is the filename, the second the contend to be written to the file. DHUN-}
  
@@ -57,7 +61,7 @@ headSplitEq c s
 {-DHUN| Removes all white space characters trailing on the right hand side of a string DHUN-}
  
 rtrim :: String -> String
-rtrim = dropWhileRev isSpace
+rtrim = reverse . (dropWhile isSpace) . reverse
  
 {-DHUN| The first parameter is an original item. The second parameter is a replacement item. The third parameter is a list. This function replaces all occurrences of the original item, with the replacement item in the list. DHUN-}
  
