@@ -15,12 +15,13 @@ if __name__ == '__main__':
     os.chdir("..")
     for i in os.listdir("."):
         if i.split(".")[-1] == "hs":
+            print (i)
             f = open(i)
             S = f.read().replace("{-DHUN", "{-").replace("DHUN-}", "-}")
             f.close()
             f = open("../" + i, "w")
-            f.write(S.split("\n")[0]+"\n" +
-                    " ".join(S.split("\n")[1].split(" ")[0:2]) + 
+            f.write("\n".join(S.split("\n")[0:whereindex(S)])+"\n" +
+                    " ".join(S.split("\n")[whereindex(S)].split(" ")[0:2]) + 
                     " where" + "\n" +
                     "\n".join(S.split("\n")[whereindex(S) + 1:]))
             f.close()
