@@ -13,7 +13,7 @@ import Hex
 import Server
 import System.FilePath.Posix
 import System.Info
-import SelfTest
+import Compiler (runCompile)
 import Tools (replace2)
  
 {-DHUN| Data structure to repesent a single option on the command line. DHUN-}
@@ -31,6 +31,7 @@ data Flag = Verbose
           | LibDir String
           | Featured String
           | MediaWiki
+          | BookMode
           | HTML
           | InternalTemplates
           | Hex String
@@ -92,6 +93,11 @@ url = "url"
 mediawiki :: String
 mediawiki = "mediawiki"
  
+{-DHUN| String constant on for the book-namespace command line option. DHUN-}
+ 
+bookmode :: String
+bookmode = "bookmode"
+
 {-DHUN| String constant on for the html command line option. DHUN-}
  
 html :: String
@@ -158,6 +164,8 @@ options
        "use MediaWiki to expand templates",
      Option ['h'] [html] (NoArg Main.HTML)
        "use MediaWiki generated html as input (default)",
+     Option ['k'] [bookmode] (NoArg BookMode)
+       "use book-namespace mode for expansion",
      Option ['z'] [Main.zip] (NoArg Main.Zip)
        "output zip archive of latex source",
      Option ['b'] [epubOption] (NoArg Main.EPub)
@@ -191,7 +199,7 @@ header = "Usage: mediawiki2latex [OPTION...]"
  
 versionHeader :: String
 versionHeader
-  = "mediawiki2latex version 7.27\n" ++ (usageInfo header options)
+  = "mediawiki2latex version 7.29\n" ++ (usageInfo header options)
  
 {-DHUN| print the version string of mediawiki2latex. Takes the output of the compilerOpts function as input. Prints the version string if no options were given or the version command was given does noting otherwise DHUN-}
  
@@ -313,7 +321,7 @@ checkOpts cwd o
                                                                inputUrl = "", runMode = ImperativeState.HTML,
                                                                paper = "A4", vector = False,
                                                                ImperativeState.copy = Nothing, mainPath = "",
-                                                               server = Nothing, selfTest = Just (s,e), outputType=PlainPDF}
+                                                               server = Nothing, selfTest = Just (s,e), outputType=PlainPDF, compile=Nothing, imgctrb=Nothing}
 
                          _ -> Left (NotIntegerPairError featuredOption)
         _ -> case serverVal of
@@ -324,11 +332,11 @@ checkOpts cwd o
                                                   inputUrl = "", runMode = ImperativeState.HTML,
                                                   paper = "A4", vector = False,
                                                   ImperativeState.copy = Nothing, mainPath = "",
-                                                  server = Just z, outputType=PlainPDF, selfTest=Nothing}
+                                                  server = Just z, outputType=PlainPDF, selfTest=Nothing, compile=Nothing, imgctrb= Nothing}
                          _ -> Left (NotIntegerError serverOption)
               _ -> do hexVal <- atMostOne hexPredicate hexen o
                       case hexVal of
-                       Just x -> return ((read . unhex) x)
+                       Just x -> do return ((read . unhex) x)
                        _ -> do resolutionOpt <- atMostOne resolutionPredicate
                                                   resolutionOption
                                                   o
@@ -353,6 +361,7 @@ checkOpts cwd o
                                                            then Right x else Left PaperError
                                                _ -> Right defaultPaper
                                let mediaWikiVal = (MediaWiki `elem` o)
+                               let bookModeVal = (BookMode `elem` o)
                                let htmlVal = (Main.HTML `elem` o)
                                let zipVal = (Main.Zip `elem` o)
                                let epubVal = (Main.EPub `elem` o)
@@ -362,7 +371,7 @@ checkOpts cwd o
                                let mysum
                                      = (boolToInt temVal) + (boolToInt mediaWikiVal) +
                                          (boolToInt htmlVal)
-                                         + (maybeToInt templatesVal)
+                                         + (maybeToInt templatesVal) + (boolToInt bookModeVal)
                                if mysum > 1 then Left ToManyOptionsError else Right ()
                                if ((boolToInt zipVal) + (boolToInt epubVal) + (boolToInt odtVal)) > (1 :: Integer) then Left ToManyOutputOptionsError else Right ()
                                runModeVal <- if mysum == (1 :: Integer) then
@@ -371,7 +380,8 @@ checkOpts cwd o
                                                    _ -> if mediaWikiVal then Right ExpandedTemplates
                                                           else
                                                           if htmlVal then Right ImperativeState.HTML
-                                                            else Right (StandardTemplates)
+                                                            else if bookModeVal then Right ImperativeState.Book
+                                                              else Right (StandardTemplates)
                                                else Right ImperativeState.HTML
                                return
                                  (FullConfig{ImperativeState.headers =
@@ -381,7 +391,7 @@ checkOpts cwd o
                                              paper = paperVal, vector = vectorVal,
                                              copy = copyVal >>= (return . (cwd </>)),
                                              mainPath = cwd ++ (if os == "linux" then "" else "\\"),
-                                             server = Nothing, outputType=if zipVal then ZipArchive else if epubVal then EPubFile else if odtVal then OdtFile else PlainPDF})
+                                             server = Nothing, outputType=if zipVal then ZipArchive else if epubVal then EPubFile else if odtVal then OdtFile else PlainPDF,compile=Nothing,imgctrb=Nothing})
  
 {-DHUN| main entry point of mediawiki2latex DHUN-}
  
@@ -393,14 +403,19 @@ main
        stz <- imperativeStateZero
        cwd <- getCurrentDirectory
        case (checkOpts cwd (fst o)) of
-           Right x -> case (selfTest x) of
-                       Just (s,e)->runSelfTest s e
-                       _-> case (server x) of
-                            Just zz -> serve zz
-                            _ -> do (xx, _) <- (runStateT (runExceptT (All.all x))
-                                                stz)
-                                    case xx of
-                                      Left n -> print n
-                                      _ -> return ()
+           Right x -> case (compile x) of
+                       Just dir -> do _ <- (runStateT (runExceptT (runCompile dir)) stz)
+                                      return ()
+                       _-> case (imgctrb x) of
+                             Just dir -> do _ <- (runStateT (runExceptT (runCtrb dir)) stz)
+                                            return ()
+                             _-> case (server x) of
+                                   Just zz -> serve zz
+                                   _ -> do print x
+                                           (xx, _) <- (runStateT (runExceptT (All.all x))
+                                                       stz)
+                                           case xx of
+                                             Left n -> print n
+                                             _ -> return ()
            Left y -> print y
        return ()
